build method
Describes the part of the user interface represented by this widget.
The framework calls this method when this widget is inserted into the tree in a given BuildContext and when the dependencies of this widget change (e.g., an InheritedWidget referenced by this widget changes). This method can potentially be called in every frame and should not have any side effects beyond building a widget.
The framework replaces the subtree below this widget with the widget returned by this method, either by updating the existing subtree or by removing the subtree and inflating a new subtree, depending on whether the widget returned by this method can update the root of the existing subtree, as determined by calling Widget.canUpdate.
Typically implementations return a newly created constellation of widgets that are configured with information from this widget's constructor and from the given BuildContext.
The given BuildContext contains information about the location in the tree at which this widget is being built. For example, the context provides the set of inherited widgets for this location in the tree. A given widget might be built with multiple different BuildContext arguments over time if the widget is moved around the tree or if the widget is inserted into the tree in multiple places at once.
The implementation of this method must only depend on:
- the fields of the widget, which themselves must not change over time, and
- any ambient state obtained from the
contextusing BuildContext.dependOnInheritedWidgetOfExactType.
If a widget's build method is to depend on anything else, use a StatefulWidget instead.
See also:
- StatelessWidget, which contains the discussion on performance considerations.
Implementation
@override
Widget build(BuildContext context) {
final theme = Theme.of(context);
final inputTheme = theme.inputDecorationTheme;
// Optimisation des calculs de base
final bool hasError = isInError == true;
final bool hasPrefix = prefixText != null && prefixText!.isNotEmpty;
final bool hasSuffix = suffixWidget != null;
// Récupérer le border radius depuis le thème de manière sécurisée
final double borderRadius =
inputTheme.enabledBorder is OutlineInputBorder
? (inputTheme.enabledBorder as OutlineInputBorder)
.borderRadius
.topLeft
.x
: AppSpacing.sm;
// Configuration des styles de texte
final textStyle = AppTypography.getScaledStyle(
AppTypography.bodyLarge,
size,
);
// Déterminer la couleur pour l'état d'erreur de manière sécurisée
final Color errorColor =
inputTheme.errorBorder is OutlineInputBorder
? (inputTheme.errorBorder as OutlineInputBorder).borderSide.color
: AppColors.red.s300;
// Style pour le hint et le préfixe
final hintStyle =
hasError
? textStyle.copyWith(color: errorColor)
: textStyle.copyWith(color: inputTheme.hintStyle?.color);
// Bordures selon l'état avec valeurs par défaut
final InputBorder defaultBorder = OutlineInputBorder(
borderRadius: BorderRadius.circular(borderRadius),
);
final InputBorder defaultErrorBorder = OutlineInputBorder(
borderRadius: BorderRadius.circular(borderRadius),
borderSide: BorderSide(color: errorColor),
);
final InputBorder activeBorder =
hasError
? (inputTheme.errorBorder ?? defaultErrorBorder)
: (inputTheme.enabledBorder ?? defaultBorder);
final InputBorder focusedBorder =
hasError
? (inputTheme.focusedErrorBorder ?? defaultErrorBorder)
: (inputTheme.focusedBorder ?? defaultBorder);
// Couleur de fond du préfixe
final Color prefixBackgroundColor =
hasError ? AppColors.red.withAlpha(10) : AppColors.gray.s50;
// Couleur de fond pour l'état désactivé (light mode: AppColors.gray.s100, dark mode: AppColors.gray.s700)
Color? fillColor = backgroundColor ?? inputTheme.fillColor;
if (disabled) {
// Utiliser une couleur de fond spécifique pour l'état désactivé
fillColor =
theme.brightness == Brightness.light
? AppColors
.gray
.s50 // Mode clair
: AppColors.gray.s700; // Mode sombre
}
final textField = TextField(
controller: controller,
style: textStyle,
focusNode: focusNode,
autofocus: autofocus,
onSubmitted: onSubmitted,
textInputAction: textInputAction,
enabled: !disabled,
decoration: InputDecoration(
hintText: placeholder,
hintStyle: hintStyle,
contentPadding: AppSizes.getInputPadding(size),
constraints: AppSizes.getInputConstraints(size),
enabledBorder: activeBorder,
focusedBorder: focusedBorder,
filled:
true, // Toujours remplir pour que la couleur de fond soit appliquée
fillColor: fillColor,
prefixIcon:
hasPrefix
? _buildPrefix(
borderRadius: borderRadius,
style: hintStyle,
backgroundColor: prefixBackgroundColor,
)
: null,
suffixIcon: hasSuffix ? suffixWidget : null,
disabledBorder: inputTheme.disabledBorder ?? defaultBorder,
border: inputTheme.border ?? defaultBorder,
),
);
final wrappedTextField = Semantics(
label: semanticsLabel ?? placeholder,
textField: true,
child: builder != null ? builder!(context, textField) : textField,
);
return wrappedTextField;
}