SFResponsiveGrid class

Grille responsive qui adapte automatiquement le nombre de colonnes

Inheritance

Constructors

SFResponsiveGrid({required List<Widget> children, int? mobileColumns, int? tabletColumns, int? desktopColumns, int? largeDesktopColumns, double? spacing, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, double? maxWidth, bool maximize = false, WrapAlignment alignment = WrapAlignment.start, double? runSpacing, Key? key})

Properties

alignment WrapAlignment
Alignement des éléments dans la grille
final
children List<Widget>
Enfants de la grille
final
desktopColumns int?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
largeDesktopColumns int?
final
margin EdgeInsetsGeometry?
Marge autour de la grille
final
maximize bool
Mode "maximisé" pour optimiser l'utilisation de l'espace sur grands écrans
final
maxWidth double?
Largeur maximale de la grille (optionnel)
final
mobileColumns int?
Nombre de colonnes par type d'écran (null = valeur par défaut)
final
padding EdgeInsetsGeometry?
Padding à l'intérieur de la grille
final
runSpacing double?
Espacement vertical entre les lignes
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double?
Espace entre les éléments
final
tabletColumns int?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited