AppTypography class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getScaledStyle(
TextStyle baseStyle, ComponentSize size) → TextStyle - Ajuste un style de texte en fonction de la taille du composant
Constants
- bodyLarge → const TextStyle
- bodyMedium → const TextStyle
- bodySmall → const TextStyle
- displayLarge → const TextStyle
- displayMedium → const TextStyle
- displaySmall → const TextStyle
- headlineLarge → const TextStyle
- headlineMedium → const TextStyle
- headlineSmall → const TextStyle
- labelLarge → const TextStyle
- labelMedium → const TextStyle
- labelSmall → const TextStyle
- titleLarge → const TextStyle
- titleMedium → const TextStyle
- titleSmall → const TextStyle