SFToggleButton class

Un bouton de basculement entre mode clair et sombre avec animation.

Ce composant affiche une icône de soleil ou de lune selon le mode actuel, et permet à l'utilisateur de basculer entre les deux états avec une animation fluide.

onToggle est appelé avec la nouvelle valeur (true = sombre, false = clair) après chaque changement. initialValue définit l'état initial (true = sombre, false = clair). lightModeColor et darkModeColor permettent de personnaliser les couleurs des deux états. size contrôle la taille du bouton selon les tailles standard du design system.

Inheritance

Constructors

SFToggleButton({Key? key, required dynamic onToggle(bool), bool initialValue = false, Color? lightModeColor, Color? darkModeColor, Icon? lightIcon, Icon? darkIcon, Color? lightIconColor, Color? darkIconColor, ComponentSize size = ComponentSize.md})
const

Properties

darkIcon Icon?
final
darkIconColor Color?
final
darkModeColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
initialValue bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lightIcon Icon?
final
lightIconColor Color?
final
lightModeColor Color?
final
onToggle → dynamic Function(bool)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size ComponentSize
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<SFToggleButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited