SFPriceDefault class

Composant affichant un prix avec devise et période

Inheritance

Constructors

SFPriceDefault({required int value, required SFCurrency currency, required SFPricePeriod period, ComponentSize size = ComponentSize.md, bool showPeriod = true, bool useCurrencyCode = false, Key? key})
const

Properties

currency SFCurrency
Devise du prix
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
period SFPricePeriod
Période de facturation
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showPeriod bool
Indique si la période doit être affichée
final
size ComponentSize
Taille du composant
final
useCurrencyCode bool
Indique si le code de la devise doit être utilisé au lieu du symbole
final
value int
Valeur en centimes (ex: 999 pour 9,99€)
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited