EmptyLocalizations class
Implémentation par défaut si Localizations n'est pas disponible
- Implemented types
Constructors
- EmptyLocalizations()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
translate(
String key, {Map< String, String> ? args}) → String -
Méthode pour obtenir une traduction
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited