SFCurrency enum

Énumération des devises supportées par l'application

Inheritance
Available extensions

Values

eur → const SFCurrency
usd → const SFCurrency
gbp → const SFCurrency
jpy → const SFCurrency
cad → const SFCurrency
aud → const SFCurrency
chf → const SFCurrency

Properties

code String
Retourne le code ISO de la devise
no setter
decimalPlaces int
Retourne le nombre de décimales à afficher
no setter
decimalSeparator String
Retourne le séparateur décimal (point ou virgule)
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol String
Retourne le symbole de la devise
no setter
symbolBeforeValue bool
Retourne si le symbole est placé avant ou après le montant
no setter
symbolSpacing double
Retourne l'espacement entre le symbole et le montant
no setter

Methods

format(int valueInCents, {bool includeCurrencyCode = false}) String

Available on SFCurrency, provided by the CurrencyFormatting extension

Formatte un montant selon les règles de la devise
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SFCurrency>
A constant List of the values in this enum, in order of their declaration.