SFPricePeriod enum

Enumération des périodes de tarification possibles

Inheritance
Available extensions

Values

day → const SFPricePeriod
week → const SFPricePeriod
month → const SFPricePeriod
year → const SFPricePeriod
lifetime → const SFPricePeriod

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
label String
Retourne la représentation textuelle de la période
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SFPricePeriod>
A constant List of the values in this enum, in order of their declaration.