ProfileFormData class
Données pour les textes du formulaire de profil
Constructors
- ProfileFormData({required String labelUsername, required String labelEmail, required String placeholderUsername, required String placeholderEmail, required String errorUsernameRequired, required String errorEmailInvalid, required String saveButton, required String logoutButton, required String deleteButton})
-
const
Properties
- deleteButton → String
-
final
- errorEmailInvalid → String
-
final
- errorUsernameRequired → String
-
Messages d'erreur
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- labelEmail → String
-
final
- labelUsername → String
-
Labels pour les champs
final
- logoutButton → String
-
final
- placeholderEmail → String
-
final
- placeholderUsername → String
-
Placeholders pour les champs
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- saveButton → String
-
Textes des boutons
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Convertit les données en Map pour la compatibilité avec le code existant
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited