SFBreakpoints class
Configuration système pour la responsivité
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getColumnsForScreenSize(
SFScreenSize size) → int - Obtient le nombre de colonnes pour une taille d'écran
-
getHorizontalMargin(
SFScreenSize size) → double - Récupère la marge horizontale pour un type d'écran
-
getOrientation(
BuildContext context) → SFScreenOrientation - Détermine l'orientation de l'écran
-
getScreenSize(
BuildContext context) → SFScreenSize - Détermine la taille de l'écran en fonction de la largeur
Constants
- defaultColumns → const int
- defaultGap → const double
- Espacement entre les éléments
- desktopBreakpoint → const double
- desktopColumns → const int
-
horizontalMargins
→ const Map<
SFScreenSize, double> - Marges horizontales par type d'écran
- largeDesktopBreakpoint → const double
- largeDesktopColumns → const int
- mobileBreakpoint → const double
- Seuils de largeur pour chaque type d'écran
- mobileColumns → const int
- Nombre de colonnes par défaut pour chaque type d'écran
- tabletBreakpoint → const double
- tabletColumns → const int