SFColumnSystem class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
calculateWidthFactor(
int span, int totalColumns) → double -
getEffectiveSpan(
{required SFScreenSize screenSize, int? xs, int? sm, int? md, int? lg, int defaultSpan = defaultTotalColumns}) → int
Constants
- defaultTotalColumns → const int