AppSizes class

Classe utilitaire pour gérer les dimensions basées sur les tailles standardisées

Constructors

AppSizes()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getBorderCircular(ComponentSize size) BorderRadius
getButtonPadding(ComponentSize size) EdgeInsets
getButtonSize(ComponentSize size) Size
getCircularButtonPadding(ComponentSize size) double
Retourne le padding pour les boutons circulaires selon la taille du composant
getIconSize(ComponentSize size) double
Retourne la taille de l'icône selon la taille du composant
getInputConstraints(ComponentSize size) BoxConstraints
Retourne les contraintes BoxConstraints pour les inputs selon leur taille
getInputPadding(ComponentSize size) EdgeInsets
Convertit une taille de composant en EdgeInsets pour le padding des inputs
getPadding(ComponentSize size) EdgeInsets
Convertit une taille de composant en EdgeInsets pour le padding
getRadius(ComponentSize size) double