SFSocialProof class
Widget affichant une preuve sociale avec des avatars et un texte.
Ce composant permet d'afficher une preuve sociale visuelle qui combine des avatars d'utilisateurs avec un texte descriptif. Idéal pour montrer l'adoption d'un produit ou service par d'autres utilisateurs.
Cas d'utilisation
- Afficher le nombre d'utilisateurs qui utilisent déjà un produit
- Montrer des témoignages avec les avatars des clients
- Indiquer combien de personnes ont participé à une action spécifique
- Valoriser une fonctionnalité en montrant son adoption par d'autres utilisateurs
Exemple
SFSocialProof(
imageUrls: ['https://example.com/avatar1.jpg', 'https://example.com/avatar2.jpg'],
text: '1243 personnes ont déjà souscrit à cette offre',
)
imageUrls Liste des URLs des images d'avatars. text Texte descriptif à afficher. imageSize Taille des images d'avatar (par défaut 40.0). spacing Espacement entre les éléments. maxWidth Largeur maximale du composant (par défaut 80% de l'écran). semanticsLabel Texte personnalisé pour l'accessibilité (lecteurs d'écran).
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SFSocialProof
Constructors
-
SFSocialProof({Key? key, required List<
String> imageUrls, required String text, double imageSize = 40.0, ComponentSize spacing = ComponentSize.md, double? maxWidth, String? semanticsLabel}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageSize → double
-
final
-
imageUrls
→ List<
String> -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxWidth → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticsLabel → String?
-
final
- spacing → ComponentSize
-
final
- text → String
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited