NotificationService class
Constructors
- NotificationService()
-
factory
- NotificationService.internal(NotificationManager _manager)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
adaptNotificationWithCallback(
Widget notification, VoidCallback closeCallback) → Widget - Adapte une notification avec un callback de fermeture spécifique Cette méthode est utilisée par OverlayNotificationManager
-
closeAllNotifications(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerAdapter(
NotificationAdapter adapter) → void - Enregistre un nouvel adaptateur de notification
-
showNotification(
BuildContext context, Widget notification, {Duration duration = const Duration(seconds: 4), EdgeInsets margin = const EdgeInsets.only(top: 16, right: 16), bool requireSafeArea = true, VoidCallback? onClosed}) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
setInstance(
NotificationService instance) → void