NotificationAdapterRegistry class
Registre des adaptateurs de notification disponibles
Constructors
- NotificationAdapterRegistry()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
adaptNotification(
Widget notification, VoidCallback closeCallback) → Widget - Adapte une notification si un adaptateur est disponible, sinon retourne l'original
-
clearAdapters(
) → void -
findAdapterFor(
Widget notification) → NotificationAdapter? - Trouve un adaptateur capable de gérer le widget donné ou retourne null
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerAdapter(
NotificationAdapter adapter) → void - Enregistre un nouvel adaptateur dans le registre
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited