SFNotificationAdapter class
Adaptateur pour les notifications de type SFNotification.
Cet adaptateur permet d'intégrer les notifications SFNotification dans le système de gestion de notifications en s'assurant que les rappels de fermeture sont correctement gérés.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
adaptNotification(
Widget notification, VoidCallback closeCallback) → Widget -
Adapte la notification pour assurer la gestion correcte des rappels de fermeture.
override
-
canHandle(
Widget notification) → bool -
Vérifie si cette notification peut être gérée par cet adaptateur.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited