OverlayNotificationManager class

Implemented types

Constructors

OverlayNotificationManager({TimerProvider? timerProvider})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

closeAll() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show(BuildContext context, Widget notification, {Duration duration = const Duration(seconds: 4), EdgeInsets margin = const EdgeInsets.only(top: 16, right: 16), bool requireSafeArea = true, VoidCallback? onClosed}) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited